use anyhow::Result;
use serde::{Deserialize, Serialize};
use std::collections::HashMap;
use std::fs;

#[derive(Debug, Serialize, Deserialize)]
pub struct Config {
    pub game_version: String,
    pub loader: String,
    pub projects: HashMap<String, String>,
}

impl Config {
    pub fn get() -> Result<Self> {
        let config_raw = fs::read_to_string(".packium.toml")?;

        let config = toml::from_str(&config_raw)?;

        Ok(config)
    }

    pub fn save(&self) -> Result<()> {
        let config_toml = toml::to_string_pretty(&self)?;

        fs::write(".packium.toml", &config_toml)?;

        Ok(())
    }

    pub fn init(game_version: String, loader: String) -> Result<Self> {
        let config = Self {
            game_version,
            loader,
            projects: HashMap::new(),
        };

        config.save()?;

        Ok(config)
    }

    pub fn add(project_id: String, version_id: String) -> Result<Self> {
        let mut config = Self::get()?;

        config.projects.insert(project_id, version_id);
        config.save()?;

        Ok(config)
    }
}
