use super::versions::ProjectVersion;
use super::API_BASE_URL;
use anyhow::{bail, Result};
use serde::Deserialize;

type ProjectVersionResponse = Vec<ProjectVersion>;

pub async fn get_project_versions(
    project_id: &str,
    game_version: &str,
) -> Result<ProjectVersionResponse> {
    let url = format!(
        "{API_BASE_URL}/project/{}/version?game_versions=[\"{}\"]",
        project_id, game_version
    );

    let response = reqwest::get(url)
        .await?
        .json::<ProjectVersionResponse>()
        .await;

    match response {
        Ok(r) => Ok(r),
        Err(err) => bail!("Error with Modrinth API: {}", err.to_string()),
    }
}

type ProjectResponse = Vec<Project>;

#[derive(Debug, Deserialize)]
pub struct Project {
    slug: String,
    pub title: String,
    pub description: String,
    pub downloads: i64,
    pub id: String,
    pub followers: i64,
}

pub async fn get_multiple_projects(version_ids: Vec<&String>) -> Result<ProjectResponse> {
    let version_ids_json = serde_json::to_string(&version_ids)?;

    let url = format!("{API_BASE_URL}/projects?ids={}", version_ids_json);

    let response = reqwest::get(url).await?.json::<ProjectResponse>().await;

    match response {
        Ok(r) => Ok(r),
        Err(err) => bail!("Error with Modrinth API: {}", err.to_string()),
    }
}
