use super::API_BASE_URL;
use anyhow::{bail, Result};
use serde::Deserialize;

type Response = Vec<MinecraftVersion>;

#[derive(Debug, Deserialize)]
pub struct MinecraftVersion {
    pub version: String,
    pub version_type: String,
    date: String,
    major: bool,
}

pub async fn get_minecraft_versions() -> Result<Response> {
    let url = format!("{API_BASE_URL}/tag/game_version");

    let response = reqwest::get(url).await?.json::<Response>().await;

    match response {
        Ok(r) => Ok(r),
        Err(err) => bail!("Error with Modrinth API: {}", err.to_string()),
    }
}

#[cfg(test)]
mod tests {
    use super::*;

    #[tokio::test]
    async fn test_game_versions() {
        let response = get_minecraft_versions().await;

        assert!(response.is_ok())
    }
}
