use super::API_BASE_URL;
use anyhow::{bail, Result};
use serde::Deserialize;

type Response = Vec<ProjectVersion>;

#[derive(Debug, Deserialize)]
pub struct ProjectVersion {
    pub name: String,
    pub version_number: String,
    game_versions: Vec<String>,
    version_type: String,
    loaders: Vec<String>,
    featured: bool,
    pub id: String,
    project_id: String,
    downloads: i64,
}

pub async fn get_multiple_versions(version_ids: Vec<&String>) -> Result<Response> {
    let version_ids_json = serde_json::to_string(&version_ids)?;

    let url = format!("{API_BASE_URL}/versions?ids={}", version_ids_json);

    let response = reqwest::get(url).await?.json::<Response>().await;

    match response {
        Ok(r) => Ok(r),
        Err(err) => bail!("Error with Modrinth API: {}", err.to_string()),
    }
}
